summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJames Walker <walkah@walkah.net>2010-02-22 09:03:42 -0500
committerJames Walker <walkah@walkah.net>2010-02-22 09:03:42 -0500
commit8fe097d7d165a002f3289c197a0d4ac89e02933e (patch)
treef0b4ea46c5056ad361fa0683ea3c289661bf3c4b
parent7b2ea7aa224c64cb0e44d4d445e07631a4cfeae3 (diff)
parent75fdef209245bf9424d4b995a42e4dfd980469d2 (diff)
Merge remote branch 'statusnet/testing' into testing
-rw-r--r--classes/Profile.php51
-rw-r--r--lib/atom10feed.php4
-rw-r--r--lib/atomusernoticefeed.php3
-rw-r--r--plugins/OStatus/classes/Ostatus_profile.php4
-rw-r--r--plugins/OStatus/lib/activity.php9
-rw-r--r--plugins/OpenID/doc-src/openid2
6 files changed, 64 insertions, 9 deletions
diff --git a/lib/atom10feed.php b/lib/atom10feed.php
index 5e17b20d3..8842840d5 100644
--- a/lib/atom10feed.php
+++ b/lib/atom10feed.php
@@ -109,11 +109,11 @@ class Atom10Feed extends XMLStringer
);
}
- if (!is_null($uri)) {
+ if (isset($uri)) {
$xs->element('uri', null, $uri);
}
- if (!is_null(email)) {
+ if (isset($email)) {
$xs->element('email', null, $email);
}
diff --git a/lib/atomusernoticefeed.php b/lib/atomusernoticefeed.php
index f71c721fe..2ad8de455 100644
--- a/lib/atomusernoticefeed.php
+++ b/lib/atomusernoticefeed.php
@@ -60,8 +60,7 @@ class AtomUserNoticeFeed extends AtomNoticeFeed
$this->user = $user;
if (!empty($user)) {
$profile = $user->getProfile();
- $this->addAuthor($profile->getBestName(),
- $user->uri);
+ $this->addAuthor($profile->nickname, $user->uri);
}
}
diff --git a/plugins/OStatus/classes/Ostatus_profile.php b/plugins/OStatus/classes/Ostatus_profile.php
index 71885bcdc..0e12f8fc6 100644
--- a/plugins/OStatus/classes/Ostatus_profile.php
+++ b/plugins/OStatus/classes/Ostatus_profile.php
@@ -832,7 +832,9 @@ class Ostatus_profile extends Memcached_DataObject
protected static function getActivityObjectNickname($object, $hints=array())
{
- // XXX: check whatever PoCo calls a nickname first
+ if (!empty($object->nickname)) {
+ return common_nicknamize($object->nickname);
+ }
// Try the definitive ID
diff --git a/plugins/OStatus/lib/activity.php b/plugins/OStatus/lib/activity.php
index af83f8bc6..a26248f19 100644
--- a/plugins/OStatus/lib/activity.php
+++ b/plugins/OStatus/lib/activity.php
@@ -31,6 +31,12 @@ if (!defined('STATUSNET')) {
exit(1);
}
+class PoCo
+{
+ const NS = 'http://portablecontacts.net/spec/1.0';
+ const USERNAME = 'preferredUsername';
+}
+
/**
* Utilities for turning DOMish things into Activityish things
*
@@ -319,7 +325,8 @@ class ActivityObject
$this->displayName = $this->title;
// @fixme we may have multiple avatars with different resolutions specified
- $this->avatar = ActivityUtils::getLink($element, 'avatar');
+ $this->avatar = ActivityUtils::getLink($element, 'avatar');
+ $this->nickname = ActivityUtils::childContent($element, PoCo::USERNAME, PoCo::NS);
}
}
diff --git a/plugins/OpenID/doc-src/openid b/plugins/OpenID/doc-src/openid
index c741e3674..f2dc610a5 100644
--- a/plugins/OpenID/doc-src/openid
+++ b/plugins/OpenID/doc-src/openid
@@ -3,7 +3,7 @@
If you already have an account on %%site.name%%, you can [login](%%action.login%%) with your username and password as usual.
To use OpenID in the future, you can [add an OpenID to your account](%%action.openidsettings%%) after you have logged in normally.
-There are many [Public OpenID providers](http://wiki.openid.net/Public_OpenID_providers), and you may already have an OpenID-enabled account on another service.
+There are many [Public OpenID providers](http://wiki.openid.net/OpenID-Providers), and you may already have an OpenID-enabled account on another service.
* On wikis: If you have an account on an OpenID-enabled wiki, like [Wikitravel](http://wikitravel.org/), [wikiHow](http://www.wikihow.com/), [Vinismo](http://vinismo.com/), [AboutUs](http://aboutus.org/) or [Keiki](http://kei.ki/), you can log in to %%site.name%% by entering the **full URL** of your user page on that other wiki in the box above. For example, *http://kei.ki/en/User:Evan*.
* [Yahoo!](http://openid.yahoo.com/) : If you have an account with Yahoo!, you can log in to this site by entering your Yahoo!-provided OpenID in the box above. Yahoo! OpenID URLs have the form *https://me.yahoo.com/yourusername*.
diff --git a/classes/Profile.php b/classes/Profile.php
index 5ff746e30..7fb2b87bc 100644
--- a/classes/Profile.php
+++ b/classes/Profile.php
@@ -792,9 +792,11 @@ class Profile extends Memcached_DataObject
* Returns an XML string fragment with profile information as an
* Activity Streams noun object with the given element type.
*
* Assumes that 'activity' namespace has been previously defined.
*
* @param string $element one of 'actor', 'subject', 'object', 'target'
+ *
* @return string
*/
function asActivityNoun($element)
@@ -811,9 +813,52 @@ class Profile extends Memcached_DataObject
'id',
null,
$this->getUri()
- );
+ );
+
+ // title should contain fullname
$xs->element('title', null, $this->getBestName());
+ $xs->element('link', array('rel' => 'alternate',
+ 'type' => 'text/html'),
+ $this->profileurl);
+
+ $xs->element('poco:preferredUsername', null, $this->nickname);
+
+ // Portable Contacts stuff
+
+ if (isset($this->bio)) {
+
+ // XXX: Possible to use OpenSocial's aboutMe?
+
+ $xs->element('poco:note', null, $this->bio);
+ }
+
+ if (isset($this->homepage)) {
+
+ $xs->elementStart('poco:urls');
+ $xs->element('poco:value', null, $this->homepage);
+ $xs->element('poco:type', null, 'homepage');
+ $xs->element('poco:primary', null, 'true');
+ $xs->elementEnd('poco:urls');
+ }
+
+ if (isset($this->location)) {
+ $xs->elementStart('poco:address');
+ $xs->element('poco:formatted', null, $this->location);
+ $xs->elementEnd('poco:address');
+ }
+
+ if (isset($this->lat) && isset($this->lon)) {
+ $this->element(
+ 'georss:point',
+ null,
+ (float)$this->lat . ' ' . (float)$this->lon
+ );
+ }
+
+ // XXX: Should we send all avatar sizes we have? I think
+ // cliqset does -Z
+
$avatar = $this->getAvatar(AVATAR_PROFILE_SIZE);
$xs->element(
@@ -829,6 +874,8 @@ class Profile extends Memcached_DataObject
$xs->elementEnd('activity:' . $element);
+ // XXX: Add people tags with <poco:tags> plural?
+
return $xs->getString();
}
@@ -792,9 +792,11 @@ class Profile extends Memcached_DataObject
* Activity Streams noun object with the given element type.
*
- * Assumes that 'activity' namespace has been previously defined.
+ * Assumes that 'activity', 'georss', and 'poco' namespace has been
+ * previously defined.
*
* @param string $element one of 'actor', 'subject', 'object', 'target'